@@ -88,8 +88,9 @@ function table.remove(list, pos) end
 ---
 ---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-table.sort"])
 ---
----@param list table
----@param comp fun(a: any, b: any):boolean
+---@generic T
+---@param list T[]
+---@param comp? fun(a: T, b: T):boolean
 function table.sort(list, comp) end
 
 ---@version >5.2, JIT
@@ -150,4 +151,33 @@ function table.foreachi(list, callback) end
 ---@deprecated
 function table.getn(list) end
 
+---@version JIT
+---
+---This creates a pre-sized table, just like the C API equivalent `lua_createtable()`. This is useful for big tables if the final table size is known and automatic table resizing is too expensive. `narray` parameter specifies the number of array-like items, and `nhash` parameter specifies the number of hash-like items. The function needs to be required before use.
+---```lua
+---    require("table.new")
+---```
+---
+---
+---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-table.new"])
+---
+---@param narray integer
+---@param nhash integer
+---@return table
+function table.new(narray, nhash) end
+
+---@version JIT
+---
+---This clears all keys and values from a table, but preserves the allocated array/hash sizes. This is useful when a table, which is linked from multiple places, needs to be cleared and/or when recycling a table for use by the same context. This avoids managing backlinks, saves an allocation and the overhead of incremental array/hash part growth. The function needs to be required before use.
+---```lua
+---    require("table.clear").
+---```
+---Please note this function is meant for very specific situations. In most cases it's better to replace the (usually single) link with a new table and let the GC do its work.
+---
+---
+---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-table.clear"])
+---
+---@param tab table
+function table.clear(tab) end
+
 return table
