@@ -6,8 +6,10 @@ local vm     = require "vm.vm"
 
 -- 把耗时最长的诊断放到最后面
 local diagSort = {
-    ['deprecated'] = 98,
-    ['undefined-field'] = 99,
+    ['redundant-value']     = 96,
+    ['not-yieldable']       = 97,
+    ['deprecated']          = 98,
+    ['undefined-field']     = 99,
     ['redundant-parameter'] = 100,
 }
 
@@ -103,7 +105,7 @@ end
 ---@param uri uri
 ---@param isScopeDiag boolean
 ---@param response async fun(result: any)
----@param checked  async fun(name: string)
+---@param checked? async fun(name: string)
 return function (uri, isScopeDiag, response, checked)
     local ast = files.getState(uri)
     if not ast then
